@@ -34,17 +34,16 @@
 // Python version dependencies
 
 static inline CORBA::ULong
-sizeToULong(Py_ssize_t size)
+sizeToULong(Py_ssize_t size,
+            CORBA::ULong minor=_OMNI_NS(MARSHAL_StringIsTooLong))
 {
 #if (OMNI_SIZEOF_PTR == 8)
   if (size > 0xffffffff)
-    OMNIORB_THROW(MARSHAL, _OMNI_NS(MARSHAL_StringIsTooLong),
-                  CORBA::COMPLETED_NO);
+    OMNIORB_THROW(MARSHAL, minor, CORBA::COMPLETED_NO);
 #endif
   return (CORBA::ULong)size;
 }
 
-
 #if (PY_VERSION_HEX < 0x03000000) // Python 2
 
 #  define String_Check(o)                  PyString_Check(o)
@@ -52,10 +51,13 @@ sizeToULong(Py_ssize_t size)
 #  define String_FromString(s)             PyString_FromString(s)
 #  define String_FromStringAndSize(s,l)    PyString_FromStringAndSize(s,l)
 #  define String_Format(f,a)               PyString_Format(f,a)
-#  define String_GET_SIZE(o)               PyString_GET_SIZE(o)
 #  define String_AS_STRING(o)              PyString_AS_STRING(o)
 
-#  define Unicode_GET_SIZE(o)              PyUnicode_GET_SIZE(o)
+static inline CORBA::ULong
+String_GET_SIZE(PyObject* obj)
+{
+  return sizeToULong(PyString_GET_SIZE(obj));
+}
 
 static inline const char*
 String_AS_STRING_AND_SIZE(PyObject* obj, CORBA::ULong& size)
@@ -64,8 +66,14 @@ String_AS_STRING_AND_SIZE(PyObject* obj, CORBA::ULong& size)
   return PyString_AS_STRING(obj);
 }
 
+static inline CORBA::ULong
+Unicode_GET_SIZE(PyObject* obj)
+{
+  return sizeToULong(PyUnicode_GET_SIZE(obj));
+}
+
 #  define RawString_Check(o)                PyString_Check(o)
-#  define RawString_GET_SIZE(o)             PyString_GET_SIZE(o)
+#  define RawString_GET_SIZE(o)             String_GET_SIZE(o)
 #  define RawString_AS_STRING(o)            PyString_AS_STRING(o)
 #  define RawString_AS_STRING_AND_SIZE(o,s) String_AS_STRING_AND_SIZE(o,s)
 #  define RawString_FromStringAndSize(o,s)  PyString_FromStringAndSize(o,s)
@@ -82,13 +90,16 @@ String_AS_STRING_AND_SIZE(PyObject* obj, CORBA::ULong& size)
 #  if (PY_VERSION_HEX >= 0x03030000) // Python 3.3
 
 #    define String_AsString(o)               PyUnicode_AsUTF8(o)
-#    define String_GET_SIZE(o)               PyUnicode_GET_LENGTH(o)
 #    define String_AS_STRING(o)              PyUnicode_AsUTF8(o)
 
-#    define Unicode_GET_SIZE(o)              PyUnicode_GET_LENGTH(o)
+static inline CORBA::ULong
+String_GET_SIZE(PyObject* obj)
+{
+  return sizeToULong(PyUnicode_GET_LENGTH(obj));
+}
 
 static inline const char*
-String_AS_STRING_AND_SIZE(PyObject* obj, CORBA::ULong& size)  // *** HERE
+String_AS_STRING_AND_SIZE(PyObject* obj, CORBA::ULong& size)
 {
   Py_ssize_t ss;
   const char* str = PyUnicode_AsUTF8AndSize(obj, &ss);
@@ -96,6 +107,9 @@ String_AS_STRING_AND_SIZE(PyObject* obj, CORBA::ULong& size)  // *** HERE
   return str;
 }
 
+#    define Unicode_GET_SIZE(o)              String_GET_SIZE(o)
+
+
 #  else // Python 3.0, 3.1, 3.2
 
 static inline char* String_AsString(PyObject* obj)
@@ -118,9 +132,14 @@ String_AS_STRING_AND_SIZE(PyObject* obj, CORBA::ULong& size)
 }
 
 #    define String_AS_STRING(o)            String_AsString(o)
-#    define String_GET_SIZE(o)             PyUnicode_GetSize(o)
 
-#    define Unicode_GET_SIZE(o)            PyUnicode_GET_SIZE(o)
+static inline CORBA::ULong
+String_GET_SIZE(PyObject* obj)
+{
+  return sizeToULong(PyUnicode_GET_SIZE(obj));
+}
+
+#    define Unicode_GET_SIZE(o)              String_GET_SIZE(o)
 
 #  endif
 
@@ -131,13 +150,18 @@ RawString_AS_STRING_AND_SIZE(PyObject* obj, CORBA::ULong& size)
   return PyBytes_AS_STRING(obj);
 }
 
+static inline CORBA::ULong
+RawString_GET_SIZE(PyObject* obj)
+{
+  return sizeToULong(PyBytes_GET_SIZE(obj));
+}
+
 #  define String_Check(o)                  PyUnicode_Check(o)
 #  define String_FromString(s)             PyUnicode_FromString(s)
 #  define String_FromStringAndSize(s,l)    PyUnicode_FromStringAndSize(s,l)
 #  define String_Format(f,a)               PyUnicode_Format(f,a)
 
 #  define RawString_Check(o)               PyBytes_Check(o)
-#  define RawString_GET_SIZE(o)            PyBytes_GET_SIZE(o)
 #  define RawString_AS_STRING(o)           PyBytes_AS_STRING(o)
 #  define RawString_FromStringAndSize(o,s) PyBytes_FromStringAndSize(o,s)
 #  define RawString_FromString(s)          PyBytes_FromString(s)
