@@ -20,9 +20,7 @@
 //    GNU Lesser General Public License for more details.
 //
 //    You should have received a copy of the GNU Lesser General Public
-//    License along with this library; if not, write to the Free
-//    Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-//    MA 02111-1307, USA
+//    License along with this library. If not, see http://www.gnu.org/licenses/
 //
 //
 // Description:
@@ -190,7 +188,7 @@ omniPy::createPyPOACurrentObject(PortableServer::Current_ptr pc)
   self->base.obj = CORBA::Object::_duplicate(pc);
 
   omniPy::PyRefHolder args(PyTuple_New(1));
-  PyTuple_SET_ITEM(args, 0, (PyObject*)self);
+  PyTuple_SET_ITEM(args.obj(), 0, (PyObject*)self);
 
   return PyObject_CallObject(omniPy::pyPOACurrentClass, args);
 }
