@@ -90,7 +90,7 @@ public:
   }
 
   omni::s_size_t addValueBox(PyObject* d_o, PyObject* obj,
-                             omni::s_size_t current)
+                             PyObject* repoId, omni::s_size_t current)
   {
     // Look to see if the value has been marshalled before. If so,
     // return its offset; if not, add it to the table and return -1.
@@ -125,10 +125,12 @@ public:
     case CORBA::tk_wchar:
     case CORBA::tk_wstring: // kept distinct from string
       {
-        // Make a tuple of the form (id(obj), tk)
-        PyObject* ktuple = PyTuple_New(2);
+        // Make a tuple of the form (id(obj), tk, repoId)
+        Py_INCREF(repoId);
+        PyObject* ktuple = PyTuple_New(3);
         PyTuple_SET_ITEM(ktuple, 0, key);
         PyTuple_SET_ITEM(ktuple, 1, Int_FromLong(tk));
+        PyTuple_SET_ITEM(ktuple, 2, repoId);
         key = ktuple;
       }
       break;
@@ -668,8 +670,9 @@ marshalPyObjectValueBox(cdrStream& stream, PyObject* d_o, PyObject* a_o)
 
   stream.alignOutput(omni::ALIGN_4);
 
+  PyObject*      repoId    = PyTuple_GET_ITEM(d_o, 2);
   PyObject*      boxed_d_o = PyTuple_GET_ITEM(d_o, 4);
-  omni::s_size_t pos       = tracker->addValueBox(boxed_d_o, a_o,
+  omni::s_size_t pos       = tracker->addValueBox(boxed_d_o, a_o, repoId,
                                                   stream.currentOutputPtr());
 
   if (pos != -1) {
@@ -681,7 +684,6 @@ marshalPyObjectValueBox(cdrStream& stream, PyObject* d_o, PyObject* a_o)
 
   CORBA::Long tag = 0x7fffff00;
 
-  PyObject* repoId = PyTuple_GET_ITEM(d_o, 2);
 
   // ValueBoxes are only sent chunked if they're nested inside chunked values.
   if (cstreamp)
