@@ -176,12 +176,15 @@ extern "C" {
 
   static void removeDummyOmniThread(void* vself) {
     if ((omni_thread*)vself == omni_thread::self()) {
-      omniORB::logs(10, "Remove dummy omni thread.");
       omniPy::InterpreterUnlocker _u;
+      omniORB::logs(10, "Remove dummy omni thread.");
       omni_thread::release_dummy();
     }
-    else
-      omniORB::logs(5, "Unable to release dummy omni_thread.");
+    else {
+      omniPy::InterpreterUnlocker _u;
+      omniORB::logs(10, "Remove dummy omni_thread (from another thread).");
+      omni_thread::release_finished_dummy((omni_thread*)vself);
+    }
   }
 
 #else
@@ -190,12 +193,15 @@ extern "C" {
     void* vself = PyCapsule_GetPointer(cap, 0);
 
     if ((omni_thread*)vself == omni_thread::self()) {
-      omniORB::logs(10, "Remove dummy omni thread.");
       omniPy::InterpreterUnlocker _u;
+      omniORB::logs(10, "Remove dummy omni thread.");
       omni_thread::release_dummy();
     }
-    else
-      omniORB::logs(5, "Unable to release dummy omni_thread.");
+    else {
+      omniPy::InterpreterUnlocker _u;
+      omniORB::logs(10, "Remove dummy omni_thread (from another thread).");
+      omni_thread::release_finished_dummy((omni_thread*)vself);
+    }
   }
 #endif
 }
@@ -236,8 +242,8 @@ omniPy::ensureOmniThread()
   // Create a dummy omni_thread
   self = omni_thread::create_dummy();
 
-  // Create a CObject with a suitable destructor function and set it
-  // as an attribute of the current thread.
+  // Create a Capsule / CObject with a suitable destructor function
+  // and set it as an attribute of the current thread.
 #if (PY_VERSION_HEX < 0x03000000)
   PyObject* cobj = PyCObject_FromVoidPtr(self, removeDummyOmniThread);
 #else
@@ -246,18 +252,6 @@ omniPy::ensureOmniThread()
 
   PyObject_SetAttrString(current, (char*)"__omni_thread", cobj);
 
-  // Use an evil hack to make sure the __omni_thread member is
-  // released when the thread stops.
-  PyObject* hook = PyObject_CallMethod(omniPy::pyomniORBmodule,
-				       (char*)"omniThreadHook", (char*)"O",
-				       current);
-  if (!hook) {
-    omniORB::logs(1, "Unexpected exception calling omniThreadHook.");
-    if (omniORB::trace(1)) PyErr_Print();
-    PyErr_Clear();
-  }
-
-  Py_XDECREF(hook);
   Py_DECREF(cobj);
   Py_DECREF(current);
 
