@@ -35,6 +35,9 @@ Functions:
   set_CA()
   set_key()
   set_cipher_list()
+  set_ciphersuites()
+  set_min_proto_version()
+  set_max_proto_version()
   reinit()
 
 Deprecated functions:
